pub enum ServerKind {
Deferrable,
Periodic,
}Expand description
The Type of a Server
Variants
Deferrable
Indicated that the Server is a Deferrable Server as described/defined in Section 5.2 Paragraph 2 of the paper
Periodic
Indicates that the Server is a Periodic Server as described/defined in Section 5.2 Paragraph 4 of the paper