Window

Struct Window 

pub struct Window<T> {
    pub start: TimeUnit,
    pub end: WindowEnd,
    /* private fields */
}
Type representing a Window based on the papers Definition 1.

With an extra Type Parameter to indicate the Window type

Fields

start: TimeUnit

The Start point of the Window

end: WindowEnd

The End Point of the Window

Implementations

Source

impl<T> Window<T>

pub fn new<I: Into<TimeUnit>, E: Into<WindowEnd>>(start: I, end: E) -> Self

Create a new Window

pub const fn empty() -> Self

Create a new empty Window

pub fn length(&self) -> WindowEnd

Calculate the window length as defined in Definition 1. of the paper

pub fn overlaps(&self, other: &Self) -> bool

Calculate the overlap (Ω) of two windows as defined in Definition 2. of the paper

pub fn adjacent(&self, other: &Self) -> bool

Determine if two windows are adjacent, a special case of overlapping

Used by AggregationIterator to take advantage of the relaxed invariant of CurveIterator as opposed to Curve

pub fn delta<Q: WindowType>( supply: &Self, demand: &Window<Q>, ) -> WindowDeltaResult<T, Q>
where T: WindowType,

Calculate the Window delta as defined in Definition 6. of the paper

pub fn is_empty(&self) -> bool

Whether the window is empty/has a length of 0

pub fn budget_group(&self, interval: TimeUnit) -> UnitNumber

Calculate the Budget Group that the window falls into given a splitting interval

See Section 6.2 3

pub fn aggregate(&self, other: &Self) -> Option<Self>

Calculate the aggregation (⊕) of two windows as defined in Definition 4. of the paper

pub fn reclassify<R>(self) -> Window<R>